cheesecake.ast_pp.SourceWriter

Package cheesecake :: Module ast_pp :: Class SourceWriter |
[show private | hide private]
[frames | no frames]

## Type SourceWriter

    object --+
             |
            SourceWriter

Method Summary
| `__init__(self)`
| `__str__(self)`
| `dedent(self)`
| `indent(self)`
| `nl(self)`
| `visitAdd(self, node)`
| `visitAssAttr(self, node)`
| `visitAssign(self, node)`
| `visitAssName(self, node)`
| `visitAssTuple(self, node)`
| `visitAugAssign(self, node)`
| `visitCallFunc(self, node)`
| `visitClass(self, node)`
| `visitCompare(self, node)`
| `visitConst(self, node)`
| `visitDict(self, node)`
| `visitDiscard(self, node)`
| `visitFor(self, node)`
| `visitFrom(self, node)`
| `visitFunction(self, node)`
| `visitGetattr(self, node)`
| `visitIf(self, node)`
| `visitImport(self, node)`
| `visitListComp(self, node)`
| `visitListCompFor(self, node)`
| `visitMod(self, node)`
| `visitModule(self, node)`
| `visitMul(self, node)`
| `visitName(self, node)`
| `visitPrintnl(self, node)`
| `visitRaise(self, node)`
| `visitReturn(self, node)`
| `visitSlice(self, node)`
| `visitStmt(self, node)`
| `visitSub(self, node)`
| `visitSubscript(self, node)`
| `visitTryFinally(self, node)`
| `visitTuple(self, node)`
| `visitUnarySub(self, node)`
| `w(self, s)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value

Class Variable Summary
`int` | `_i` = 0

Class Variable Details

    ### _i Type: `int` Value:
        0

Generated by Epydoc 2.1 on Fri Feb 9 02:15:13 2007 | http://epydoc.sf.net